//  BMPx - The Dumb Music Player
//  Copyright (C) 2005 BMPx development team.
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License Version 2
//  as published by the Free Software Foundation.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
//  --
//
//  The BMPx project hereby grants permission for non-GPL compatible GStreamer
//  plugins to be used and distributed together with GStreamer and BMPx. This
//  permission is above and beyond the permissions granted by the GPL license
//  BMPx is covered by.

#ifndef BMP_UTIL_HH
#define BMP_UTIL_HH

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif //HAVE_CONFIG_H

#include <boost/optional.hpp>

#include <string>
#include <vector>
#include <map>

#include <glibmm.h>

namespace Bmp
{
#ifdef HAVE_HAL
  typedef std::pair   < std::string, std::string > UriVrpPair;
  typedef std::vector < UriVrpPair > VUriVrpPair;
#endif //HAVE_HAL

  typedef std::vector<Glib::ustring> VUri;
  typedef boost::optional<Glib::ustring> oustring;
  typedef boost::optional<unsigned int> ouint;
  typedef boost::optional<bool>         obool;

  namespace Util
  {
    bool
    str_has_prefix_nocase	    (const char *str, const char* prefix);
    bool
    str_has_suffix_nocase	    (const char *str, const char* suffix);
    bool
    str_has_suffixes_nocase   (const char *str, char* const *suffixes);
  }
}

#ifndef BMP_PLUGIN_BUILD

#include <glibmm.h>
#include <gtkmm.h>
#include <string>
#include <boost/function.hpp>

namespace Bmp
{

  typedef std::vector<Gtk::TreePath> PathList;
  typedef std::vector<Gtk::TreeRowReference> ReferenceList;
  typedef std::vector<Gtk::TreeModel::iterator> IterList;

  namespace Util
  {
    bool  
    daemonize ();

    bool
    match_keys (std::string haystack, std::string needle);

    char*
    hexify (char *pass, int len);

    std::string
    md5_hex (char* const data, size_t data_size);

    Glib::ustring 
    sanitize_html (Glib::ustring const& in);
 
    // Converts a RFC822 time string to a time_t value
    // Code (C) Liferea Developers
    time_t parseRFC822Date (const char * date);
 
    std::string 
    get_timestr (time_t t, int gmt);
    
    std::string
    get_time ();

    Glib::RefPtr<Gdk::Pixbuf> 
    get_image_from_uri (Glib::ustring const& uri);
  }
}
#endif // !BMP_PLUGIN_BUILD

#endif // !BMP_UTIL_HH
